@@ -26,7 +26,11 @@ module WebConsole
   end
 
   def self.logger
-    Rails.logger || (@logger ||= ActiveSupport::Logger.new($stderr))
+    (defined?(Rails.logger) && Rails.logger) || (@logger ||= ActiveSupport::Logger.new($stderr))
+  end
+
+  def self.deprecator
+    @deprecator ||= ActiveSupport::Deprecation.new("5.0", "WebConsole")
   end
 end
 
